@@ -22,13 +22,14 @@ namespace Doctrine\Test\DataFixtures\Sorter;
 
 use Doctrine\Common\DataFixtures\Sorter\Vertex;
 use Doctrine\ORM\Mapping\ClassMetadata;
+use Doctrine\Tests\Common\DataFixtures\BaseTest;
 
 /**
  * @author Marco Pivetta <ocramius@gmail.com>
  *
  * @covers \Doctrine\Common\DataFixtures\Sorter\Vertex
  */
-class VertexTest extends \PHPUnit_Framework_TestCase
+class VertexTest extends BaseTest
 {
     public function testNode()
     {
